<?php

namespace App\Http\Controllers;

use Session;
use App\Models\Category;
use App\Models\Products;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CartController extends Controller
{
    // Add a product to the cart
    public function addToCart($productId)
    {
        // Fetch the product using the productId
        $product = Products::find($productId);

        // Check if the product exists
        if ($product) {
            // Get the current cart from the session, or initialize an empty array
            $cart = session()->get('cart', []);

            // Check if the product is already in the cart
            if (isset($cart[$productId])) {
                // If product already in cart, increase the quantity
                $cart[$productId]['quantity']++;
            } else {
                // Otherwise, add the product to the cart
                $cart[$productId] = [
                    'name' => $product->name,
                    'quantity' => 1,
                    'price' => $product->price,
                    'image' => $product->image,
                ];
            }

            // Save the updated cart back to the session
            session()->put('cart', $cart);

            // Return a success message to the user
            return redirect()->back()->with('success', 'Product added to cart!');
        }

        // If the product is not found, return an error message
        return redirect()->back()->with('error', 'Product not found!');
    }

    // Display the cart
    public function showCart()
    {
        // Retrieve cart from session
        $cart = session()->get('cart');

        // Check if the cart is empty
        if ($cart) {
            return view('cart.index', compact('cart')); // pass cart to your cart view
        } else {
            return view('cart.index')->with('message', 'Your cart is empty!');
        }
    }

    // Update the quantity of a product in the cart
    public function updateCart(Request $request, $productId)
    {
        // Validate quantity
        $request->validate([
            'quantity' => 'required|integer|min:1',
        ]);

        // Retrieve cart from session
        $cart = session()->get('cart');

        // Check if the product is in the cart
        if (isset($cart[$productId])) {
            // Update the quantity of the product
            $cart[$productId]['quantity'] = $request->quantity;

            // Save updated cart to session
            session()->put('cart', $cart);

            return redirect()->back()->with('success', 'Cart updated!');
        }

        return redirect()->back()->with('error', 'Product not found in cart!');
    }

    // Remove an item from the cart
    public function removeFromCart($productId)
    {
        // Retrieve cart from session
        $cart = session()->get('cart');

        // Check if the product exists in the cart
        if (isset($cart[$productId])) {
            // Remove the product from the cart
            unset($cart[$productId]);

            // Save the updated cart to session
            session()->put('cart', $cart);

            return redirect()->back()->with('success', 'Product removed from cart!');
        }

        return redirect()->back()->with('error', 'Product not found in cart!');
    }

    // Clear all items from the cart
    public function clearCart()
    {
        // Remove the cart, subtotal, and total from the session
        session()->forget('cart');
        session()->forget('cart_subtotal');
        session()->forget('cart_total');
        return redirect()->back()->with('success', 'Cart has been cleared!');
    }

    public function add($productId)
    {
        $product = Products::find($productId);

        if (!$product) {
            return redirect()->route('shop.index')->with('error', 'Product not found');
        }

        // Add product to cart
        $cart = session()->get('cart', []);

        if (isset($cart[$productId])) {
            $cart[$productId]['quantity']++;
        } else {
            $cart[$productId] = [
                'name' => $product->name,
                'quantity' => 1,
                'price' => $product->price,
                'image' => $product->image ? $product->image : 'default.jpg',
                'category' => $product->category ? $product->category->name : 'Uncategorized',
            ];
        }

        session()->put('cart', $cart);

        // Calculate subtotal and total
        $subtotal = 0;
        foreach ($cart as $item) {
            $subtotal += $item['quantity'] * $item['price'];
        }

        session()->put('cart_subtotal', $subtotal);
        session()->put('cart_total', $subtotal);

        // Get categories
        $categories = Category::all(); // Get all categories

        return view('frontend.shoping-cart', [
            'success' => 'Product added to cart',
            'categories' => $categories
        ]);
    }

    public function remove($productId)
    {
        $cart = session()->get('cart', []);

        // Check if the product exists in the cart
        if (isset($cart[$productId])) {
            // Remove the product from the cart
            unset($cart[$productId]);

            // Update the cart in the session
            session()->put('cart', $cart);

            // Recalculate the subtotal and total
            $subtotal = 0;
            foreach ($cart as $item) {
                $subtotal += $item['quantity'] * $item['price'];
            }

            $total = $subtotal;
            session()->put('cart_subtotal', $subtotal);
            session()->put('cart_total', $total);
        }
        $categories = Category::all(); // Replace this with your actual logic for fetching categories

        // Pass variables to the view
        return view('frontend.shoping-cart', [
            'success' => 'Product removed from cart',
            'categories' => $categories
        ]);
    }
}